ScoutApm.Config (scout_apm v2.0.0)

Public interface to configuration settings. Reads from several configuration sources, giving each an opportunity to respond with its value before trying the next.

Application.get_env, and Defaults are the the current ones, with an always-nil at the end of the chain.

Summary

Functions

find(key)