ScoutApm.Config.Coercions (scout_apm v2.0.0)
Copy MarkdownTakes "raw" values from various config sources, and turns them into the requested format.
Summary
Functions
Returns {:ok, true}, {:ok, false}, or :error Attempts to "parse" a string
Takes "raw" values from various config sources, and turns them into the requested format.
Returns {:ok, true}, {:ok, false}, or :error Attempts to "parse" a string