ScoutApm.Context (scout_apm v2.0.0)

Public API for easily adding Context to a running request.

These functions must be called from the process handling the request, since the correct underlying TrackedRequest is looked up that way.

Summary

Functions

Returns :ok on success Returns {:error, {:arg, reason}} on failure

A user-specific bit of context. Gets special treatment in the UI, but otherwise follows the same rules as the add function.

Functions

add(key, value)

Returns :ok on success Returns {:error, {:arg, reason}} on failure

add_user(key, value)

A user-specific bit of context. Gets special treatment in the UI, but otherwise follows the same rules as the add function.