ScoutApm.ScopeStack (scout_apm v2.0.0)
Copy MarkdownInternal to ScoutApm agent.
Used as a helper to track the current scope a layer is under, as we build up a trace.
This doesn't have any way to pop, since it's used in a recursive call, and coppies should just be tossed as the call stack finishes