ScoutApm.Watcher (scout_apm v2.0.0)

A simple module to log when a watched process fails. Only works to watch module based workers currently, not arbitrary pids. See usage in application.ex

Summary

Functions

Returns a specification to start this module under a supervisor.

Callback implementation for GenServer.init/1.

Functions

child_spec(init_arg)

Returns a specification to start this module under a supervisor.

See Supervisor.

init(mod)

Callback implementation for GenServer.init/1.

start_link(mod)