ScoutApm.Watcher (scout_apm v2.0.0)
Copy MarkdownA simple module to log when a watched process fails. Only works to watch module based workers currently, not arbitrary pids. See usage in application.ex
Summary
Functions
Returns a specification to start this module under a supervisor.
Callback implementation for GenServer.init/1.
Functions
Returns a specification to start this module under a supervisor.
See Supervisor.
Callback implementation for GenServer.init/1.